package com.codegeist.fisheye.domain;

import static org.junit.Assert.*;

import org.junit.Test;

import com.codegeist.fisheye.domain.query.Query.AttributeType;
import com.codegeist.fisheye.domain.query.Query.ReturnValue;

public class QueryResultDataTest {

	@Test(expected=IllegalArgumentException.class)
	public void testNullColumns() throws Exception {
		new QueryResultData(null);
	}
	
	@Test(expected=IllegalArgumentException.class)
	public void testEmptyColumns() throws Exception {
		new QueryResultData(new ReturnValue[0]);
	}

	@Test
	public void testSingleColumn() throws Exception {
		QueryResultData resultData = new QueryResultData(new ReturnValue[] {new ReturnValue(AttributeType.AUTHOR)});
		resultData.addLine(new Object[] {"author1"});
		
		assertNotNull(resultData.getColumns());
		assertNotNull(resultData.getData());
		assertTrue(resultData.getData().size() == 1);
		assertEquals(resultData.getData().get(0)[0], "author1");
	}
	
	@Test(expected=IllegalArgumentException.class)
	public void testWrongType() throws Exception {
		QueryResultData resultData = new QueryResultData(new ReturnValue[] {new ReturnValue(AttributeType.AUTHOR)});
		resultData.addLine(new Object[] {Boolean.FALSE});
	}
	
	@Test(expected=IllegalArgumentException.class)
	public void testShortRow() throws Exception {
		QueryResultData resultData = new QueryResultData(new ReturnValue[] {new ReturnValue(AttributeType.AUTHOR)});
		resultData.addLine(new Object[] {});
	}
	
	@Test(expected=IllegalArgumentException.class)
	public void testLongRow() throws Exception {
		QueryResultData resultData = new QueryResultData(new ReturnValue[] {new ReturnValue(AttributeType.AUTHOR)});
		resultData.addLine(new Object[] {"author1", "foo"});
	}

}
